@@ -1,8 +1,5 @@
 package Pithub;
-{
-  $Pithub::VERSION = '0.01020';
-}
-
+$Pithub::VERSION = '0.01022';
 # ABSTRACT: Github v3 API
 
 use Moo;
@@ -70,13 +67,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01020
+version 0.01022
 
 =head1 SYNOPSIS
 
@@ -511,6 +510,26 @@ See also: L<http://developer.github.com/v3/repos/keys/>
 
 =item *
 
+L<Pithub::Repos::Stats>
+
+See also: L<http://developer.github.com/v3/repos/statistics/>
+
+    my $watching = Pithub->new->repos->stats;
+    my $watching = Pithub::Repos->new->stats;
+    my $watching = Pithub::Repos::Stats->new;
+
+=item *
+
+L<Pithub::Repos::Statuses>
+
+See also: L<http://developer.github.com/v3/repos/statuses/>
+
+    my $watching = Pithub->new->repos->statuses;
+    my $watching = Pithub::Repos->new->statuses;
+    my $watching = Pithub::Repos::Statuses->new;
+
+=item *
+
 L<Pithub::Repos::Watching>
 
 See also: L<http://developer.github.com/v3/repos/watching/>
